#!/bin/sh
echo 'name: zlib-enum
version: 0.2.2.1
id: zlib-enum-0.2.2.1-850fd31afe82d4ad04cd29118b119441

license: MIT
copyright:
maintainer: Malte Sommerkorn <malte.sommerkorn@googlemail.com>
stability: Experimental
homepage: http://github.com/maltem/zlib-enum
package-url:
synopsis: Enumerator interface for zlib compression
description: zlib-enum is a stop-gap package to provide enumeratees for
             zlib compression/decompression.
category: Codec, Compression, Enumerator
author: Paulo Tanimoto <ptanimoto@gmail.com>
pkgpath: archivers/hs-zlib-enum
exposed: True
exposed-modules: Codec.Zlib.Enum
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/zlib-enum-0.2.2.1
library-dirs: /usr/local/lib/ghc/zlib-enum-0.2.2.1
hs-libraries: HSzlib-enum-0.2.2.1
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
         bytestring-0.9.2.1-4f95f32adc23f1bc25c472a646e99581
         enumerator-0.4.19-27ff248ca60645d7b3b73b44ac567b75
         transformers-0.3.0.0-8e66ecc7d4dae2b07b2b5406908c70e4
         zlib-bindings-0.1.0.1-6d927e0e33735f35669ffeb0fae76480
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-zlib-enum-0.2.2.1/html/zlib-enum.haddock
haddock-html: /usr/local/share/doc/hs-zlib-enum-0.2.2.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
